@@ -266,7 +266,7 @@ def memmap_file_to_chunks_(
         reset_folder_(root_path)
 
         for ind, dim_slice in enumerate(range_chunked(rows, batch_size = max_rows_per_file)):
-            filename = root_path / f'{ind}.npy'
+            filename = root_path / f'{ind:05d}.npy'
             data_slice = f[dim_slice]
 
             np.save(str(filename), f[dim_slice])
@@ -292,7 +292,8 @@ def index_embeddings(
         metric_type = "l2",
         max_index_memory_usage = max_index_memory_usage,
         current_memory_available = current_memory_available,
-        should_be_memory_mappable = True,
+        make_direct_map = True
+        should_be_memory_mappable = False,
         use_gpu = torch.cuda.is_available(),
     )
 
